# jQuery UI Scale Effect

## Overview

Shrink or grow an element by a percentage factor.

### Dependencies

- Effects Core

### Example

- Demo
- View Source

Scale the element to 0%, with the hide method (center vanishing point).

    $("div").click(function () {
          $(this).hide("scale", {}, 1000);
    });

    <!DOCTYPE html>
    <html>
    <head>
      <link href="http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/themes/base/jquery-ui.css" rel="stylesheet" type="text/css"/>
      <script src="http://ajax.googleapis.com/ajax/libs/jquery/1.4/jquery.min.js"></script>
      <script src="http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/jquery-ui.min.js"></script>
      <style type="text/css">
      div { margin: 0px; width: 100px; height: 80px; background: green; border: 1px solid black; position: relative; }
    </style>

      <script>
      $(document).ready(function() {

    $("div").click(function () {
          $(this).hide("scale", {}, 1000);
    });

      });
      </script>
    </head>
    <body style="font-size:62.5%;">
      <div></div>
    </body>
    </html>

- Demo
- View Source

Scale the element to 200%, only horizontal.

    $("div").click(function () {
          $(this).effect("scale", { percent: 200, direction: 'horizontal' }, 1000);
    });

    <!DOCTYPE html>
    <html>
    <head>
      <link href="http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/themes/base/jquery-ui.css" rel="stylesheet" type="text/css"/>
      <script src="http://ajax.googleapis.com/ajax/libs/jquery/1.4/jquery.min.js"></script>
      <script src="http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/jquery-ui.min.js"></script>
      <style type="text/css">
      div { margin: 0px; width: 100px; height: 80px; background: green; border: 1px solid black; position: relative; }
    </style>

      <script>
      $(document).ready(function() {

    $("div").click(function () {
          $(this).effect("scale", { percent: 200, direction: 'horizontal' }, 1000);
    });

      });
      </script>
    </head>
    <body style="font-size:62.5%;">
      <div></div>
    </body>
    </html>

## Arguments

- ### direction

  Type:
    String
  Default:
    "both"

  The direction of the effect. Can be "both", "vertical" or "horizontal".

- ### from

  Type:
    Object

  state at beginning, usually not needed.{ height: .., width: .. }

- ### origin

  Type:
    Array
  Default:
    ['middle','center']

  the vanishing point, default for show/hide

- ### percent

  Type:
    Integer
  Default:
    0/100

  the percentage to scale to, number.

- ### scale

  Type:
    String
  Default:
    "both"

  Which areas of the element will be resized: 'both', 'box', 'content' Box resizes the border and padding of the element Content resizes any content inside of the element